@@ -13,7 +13,7 @@
  * Copyright (c) 2009-2011,
  * University of Oregon, Eugene, USA
  *
- * Copyright (c) 2009-2011, 2013, 2014, 2017,
+ * Copyright (c) 2009-2011, 2013, 2014, 2017, 2023,
  * Forschungszentrum Juelich GmbH, Germany
  *
  * Copyright (c) 2009-2011,
@@ -623,14 +623,17 @@ OPARI2_DirectiveOpenmp::FinalizeDescrs( ostream& os )
         if ( s_lang & L_F77 )
         {
             os << "\n      integer*4 pomp2_lib_get_max_threads";
+            os << "\n      external pomp2_lib_get_max_threads";
             os << "\n      logical pomp2_test_lock";
-            os << "\n      integer*4 pomp2_test_nest_lock\n";
+            os << "\n      external pomp2_test_lock";
+            os << "\n      integer*4 pomp2_test_nest_lock";
+            os << "\n      external pomp2_test_nest_lock\n";
         }
         else if ( s_lang & L_F90 )
         {
-            os << "\n      integer ( kind=4 ) :: pomp2_lib_get_max_threads";
-            os << "\n      logical :: pomp2_test_lock";
-            os << "\n      integer ( kind=4 ) :: pomp2_test_nest_lock\n";
+            os << "\n      integer ( kind=4 ), external :: pomp2_lib_get_max_threads";
+            os << "\n      logical, external :: pomp2_test_lock";
+            os << "\n      integer ( kind=4 ), external :: pomp2_test_nest_lock\n";
         }
 
         if ( !s_common_block.empty() )
